translate.storage.versioncontrol.darcs

Package translate :: Package storage :: Package versioncontrol :: Module darcs |
[hide private]
[frames] | no frames]

# Module darcs

source code

Classes | [hide private]
| darcs Class to manage items under revision control of darcs.

Functions | [hide private]
is_available() check if darcs is installed | source code

Variables | [hide private]
| __package__ = ``'``translate.storage.versioncontrol``'``

Imports: GenericRevisionControlSystem, run_command